# markipy
Small wrapper class of the most used functions.

# Basic Classes
Here the basics functionality offered by this package.
___
## Atom
The class where all the other inherit for.

## Performance 
Benchmarker class integrated into Atom to  measure the compute time of any function just with one decorator.

## Style
Provide functions to change color of the text and use emoji.

## Logger
Python logger class to plot on console or filestream.

## Filesystem
Provide two useful wrapper : File and Folder

## Watcher
Provide a watcher on folders and file. Callback for each event can be override to perform custom tasks.

## Process
Process class to run any shell command into async threads.

## Channel
Wrapper class around messages queue.

## Thread
Provide wrapper thread class with the producer, consumer paradigm.

## Yml
Wrapper class to manage files type yalm.

## Rsync
It use Process class to run rsync commands. 
  




